CIest: Confidence Interval Estimation

View source: R/CIest.R

CIestR Documentation

Confidence Interval Estimation

Description

Get the point estimate and its confidence interval with a given contrast and alpha value using the t distribution.

Usage

  CIest(Formula, Data, Term, Contrast, conf.level=0.95) 

Arguments

Formula

a conventional formula for a linear model

Data

a data.frame to be analyzed

Term

a factor name to be estimated

Contrast

a level vector. Levels are alphabetically ordered by default.

conf.level

confidence level of the confidence interval

Details

Get the point estimate and its confidence interval with a given contrast and alpha value using the t distribution.

Value

Estimate

point estimate of the input linear contrast

Lower CL

lower confidence limit

Upper CL

upper confidence limit

Std. Error

standard error of the point estimate

t value

value for the t distribution

Df

degrees of freedom

Pr(>|t|)

probability of a larger absolute t value from the t distribution with the residual degrees of freedom

Author(s)

Kyun-Seop Bae k@acr.kr

Examples

  CIest(log(CMAX) ~ SEQ/SUBJ + PRD + TRT, BEdata, "TRT", c(-1, 1), 0.90) # 90% CI

sasLM documentation built on June 15, 2026, 9:07 a.m.