Returns the sum of squares and its F value and p-value.
Df
degrees of freedom
Sum Sq
sum of squares for the set of contrasts
Mean Sq
mean square
F value
F value for the F distribution
Pr(>F)
probability of a larger F value
Arguments
L
contrast matrix. Each row is a contrast.
Formula
a conventional formula for a linear model
Data
a data.frame to be analyzed
mu
a vector of mu for the hypothesis L. The length should be equal to the row count of L.
Author
Kyun-Seop Bae k@acr.kr
Details
It performs an F test with a given set of contrasts (a matrix). It is similar to the CONTRAST clause of SAS PROC GLM. This can test the hypothesis that the linear combination (function)'s mean vector is mu.