Cor.test: Correlation test of multiple numeric columns

View source: R/Cor.test.R

Cor.testR Documentation

Correlation test of multiple numeric columns

Description

Testing correlation between numeric columns of data with the Pearson method.

Usage

  Cor.test(Data, conf.level=0.95)

Arguments

Data

a matrix or a data.frame

conf.level

confidence level

Details

It uses all numeric columns of the input data. It uses "pairwise.complete.obs" rows.

Value

Row names show which columns are used for the test.

Estimate

point estimate of correlation

Lower CL

lower confidence limit

Upper CL

upper confidence limit

t value

t value of the t distribution

Df

degrees of freedom

Pr(>|t|)

probability with the t distribution

Author(s)

Kyun-Seop Bae k@acr.kr

Examples

  Cor.test(mtcars)

sasLM documentation built on June 15, 2026, 9:07 a.m.