CumAlpha: Cumulative Alpha with various z's and ti

View source: R/CumAlpha.R

CumAlphaR Documentation

Cumulative Alpha with various z's and ti

Description

Cumulative alpha values for repeated hypothesis tests with changing bound z-values and times of test (ti).

Usage

  CumAlpha(z, side=2, ti=NULL, c0=NULL, Seed=5)

Arguments

z

vector of upper z-value bounds for the repeated hypothesis test

side

1=one-sided test, 2=two-sided test

ti

vector of times (or information amount) of test. All values should be in [0, 1] and sorted. If not specified, equal intervals are assumed.

c0

correlation matrix. If not specified, Brownian motion is assumed.

Seed

seed value for the mvtnorm::pmvnorm function

Details

It calculates cumulative alpha-values for the repeated hypothesis test with a vector of upper bound z-values. If the times of test are not specified, linear (proportional) increase of information amount and Brownian motion of z-values are assumed, i.e. the correlation is sqrt(t_i/t_j).

Value

The result is a matrix.

ti

time of test

cum.alpha

cumulative alpha values

Author(s)

Kyun-Seop Bae k@acr.kr

References

Reboussin DM, DeMets DL, Kim K, Lan KKG. Computations for group sequential boundaries using the Lan-DeMets function method. Controlled Clinical Trials. 2000;21:190-207.

Examples

  CumAlpha(z=rep(qnorm(1 - 0.05/2), 10)) # two-side Z-test with alpha=0.05 for ten times

sasLM documentation built on June 15, 2026, 9:07 a.m.