| ESTM | R Documentation |
Estimates Linear Function with a formula and a dataset.
ESTM(L, Formula, Data, conf.level=0.95)
L |
a matrix of linear function rows to be tested |
Formula |
a conventional formula for a linear model |
Data |
a |
conf.level |
confidence level of the confidence limit |
It tests rows of linear functions. A linear function means a linear combination of estimated coefficients. It is similar to the ESTIMATE statement of SAS PROC GLM. This is a convenient version of the est function.
Estimate |
point estimate of the input linear contrast |
Lower CL |
lower confidence limit |
Upper CL |
upper confidence limit |
Std. Error |
standard error of the point estimate |
t value |
value for the t distribution |
Df |
degrees of freedom |
Pr(>|t|) |
probability of a larger absolute t value from the t distribution with the residual degrees of freedom |
Kyun-Seop Bae k@acr.kr
est
ESTM(t(c(0, -1, 1)), uptake ~ Type, CO2) # Quevec - Mississippi
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.