ExitP: Exit Probability with Cumulative Z-test in Group Sequential...

View source: R/ExitP.R

ExitPR Documentation

Exit Probability with Cumulative Z-test in Group Sequential Design

Description

Exit probabilities with the given drift, upper bounds, and times of test.

Usage

  ExitP(Theta, bi, ti=NULL)

Arguments

Theta

drift value defined by Lan-DeMets. See the reference.

bi

upper bound z-values

ti

times of test. These should be in the range of [0, 1]. If omitted, even intervals are assumed.

Details

It calculates exit probabilities and cumulative exit probabilities with the given drift, upper z-bounds, and times of test. If the times of test are not given, even intervals are assumed. mvtnorm::pmvt (with noncentrality) is better than pmvnorm in calculating power and sample size. However, Lan-DeMets used the multivariate normal rather than the multivariate noncentral t distribution. This function follows Lan-DeMets for consistency with previous results.

Value

The result is a matrix.

ti

time of test

bi

upper z-bound

cum.alpha

cumulative alpha-value

Author(s)

Kyun-Seop Bae k@acr.kr

References

Reboussin DM, DeMets DL, Kim K, Lan KKG. Computations for group sequential boundaries using the Lan-DeMets function method. Controlled Clinical Trials. 2000;21:190-207.

Examples

  b0 = seqBound(ti=(1:5)/5)[, "up.bound"]
  ExitP(Theta = Drift(b0), bi = b0)

sasLM documentation built on June 15, 2026, 9:07 a.m.