OBFBound: O'Brien-Fleming bounds for cumulative Z-test in Group...

View source: R/OBFBound.R

OBFBoundR Documentation

O'Brien-Fleming bounds for cumulative Z-test in Group Sequential Design

Description

Sequential O'Brien-Fleming upper bounds for the cumulative Z-test on accumulating data. Z values are correlated. This is usually used for group sequential design.

Usage

  OBFBound(K, alpha=0.05, side=2, ti=NULL, c0=NULL)

Arguments

K

count of tests, including the final one

alpha

goal alpha value for the last test at time 0.

side

1=one-sided test, 2=two-sided test

ti

times for test. These should be in [0, 1]. If not specified, equal intervals are assumed.

c0

correlation matrix. If not specified, Brownian motion is assumed.

Details

It calculates O'Brien-Fleming upper z-bounds and cumulative alpha-values for the repeated test in group sequential design.

Value

The result is a matrix.

ti

time of test

z

O'Brien-Fleming upper z-bound

cum.alpha

cumulative alpha-value

Author(s)

Kyun-Seop Bae k@acr.kr

See Also

seqBound, PocockBound

Examples

  OBFBound(K=2)
  OBFBound(K=3)
  OBFBound(K=4)
  OBFBound(K=5)

sasLM documentation built on June 15, 2026, 9:07 a.m.