Learn R Programming

sasLM (version 1.0.1)

ORcmh: Odds Ratio of two groups with strata by the CMH method

Description

Odds ratio and its confidence interval of two groups with stratification by the Cochran-Mantel-Haenszel method

Usage

ORcmh(d0, conf.level=0.95)

Value

The following output will be returned for each stratum and the common value.

odd1

odds from the first group, y1/(n1 - y1)

odd2

odds from the second group, y2/(n2 - y2)

OR

odds ratio, odd1/odd2. The point estimate of the common OR is calculated with the MH weights.

SElog

standard error of log(OR)

lower

lower confidence limit of OR

upper

upper confidence limit of OR

Arguments

d0

A data.frame or matrix, of which each row means a stratum. This should have four columns named y1, n1, y2, and n2; y1 and y2 for events of each group, n1 and n2 for sample size of each stratum. The second group is usually the control group.

conf.level

confidence level

Author

Kyun-Seop Bae k@acr.kr

Details

It calculates the odds ratio and its confidence interval of two groups. This can be used for meta-analysis also.

See Also

RDmn1, RRmn1, ORmn1, RDmn, RRmn, ORmn, RDinv, RRinv, ORinv

Examples

Run this code
  d1 = matrix(c(25, 339, 28, 335, 23, 370, 40, 364), nrow=2, byrow=TRUE)
  colnames(d1) =  c("y1", "n1", "y2", "n2")
  ORcmh(d1)

Run the code above in your browser using DataLab