ORinv: Odds Ratio of two groups with strata by the inverse variance...

View source: R/ORinv.R

ORinvR Documentation

Odds Ratio of two groups with strata by the inverse variance method

Description

Odds ratio and its confidence interval of two groups with stratification by the inverse variance method

Usage

  ORinv(d0, conf.level=0.95)

Arguments

d0

A data.frame or matrix, of which each row means a stratum. This should have four columns named y1, n1, y2, and n2; y1 and y2 for events of each group, n1 and n2 for sample size of each stratum. The second group is usually the control group.

conf.level

confidence level

Details

It calculates the odds ratio and its confidence interval of two groups by the inverse variance method. This supports stratification. This can be used for meta-analysis also.

Value

The following output will be returned for each stratum and the common value.

odd1

odds from the first group, y1/(n1 - y1)

odd2

odds from the second group, y2/(n2 - y2)

OR

odds ratio, odd1/odd2. The point estimate of the common OR is calculated with the inverse variance weights.

SElog

standard error of log(OR)

lower

lower confidence limit of OR

upper

upper confidence limit of OR

Author(s)

Kyun-Seop Bae k@acr.kr

See Also

RDmn1, RRmn1, ORmn1, RDmn, RRmn, ORmn, RDinv, RRinv, ORcmh

Examples

  d1 = matrix(c(25, 339, 28, 335, 23, 370, 40, 364), nrow=2, byrow=TRUE)
  colnames(d1) =  c("y1", "n1", "y2", "n2")
  ORinv(d1)

sasLM documentation built on June 15, 2026, 9:07 a.m.