| ORmn1 | R Documentation |
Odds ratio and its score confidence interval of two groups without stratification
ORmn1(y1, n1, y2, n2, conf.level=0.95, eps=1e-8)
y1 |
positive event count of the test (the first) group |
n1 |
total count of the test (the first) group |
y2 |
positive event count of the control (the second) group |
n2 |
total count of the control (the second) group |
conf.level |
confidence level |
eps |
absolute value less than eps is regarded as negligible |
It calculates the odds ratio and its score confidence interval of the two groups. The confidence interval is asymmetric, and there is no standard error in the output. This does not support stratification. This implementation uses the uniroot function, which usually gives at least 5 significant digits. In contrast, the PropCIs::orscoreci function uses an incremental or decremental search by a factor of 1.001, which gives less than 3 significant digits.
There is no standard error.
odd1 |
odds from the first group, y1/(n1 - y1) |
odd2 |
odds from the second group, y2/(n2 - y2) |
OR |
odds ratio, odd1/odd2 |
lower |
lower confidence limit of OR |
upper |
upper confidence limit of OR |
Kyun-Seop Bae k@acr.kr
Miettinen O, Nurminen M. Comparative analysis of two rates. Stat Med 1985;4:213-26
RDmn1, RRmn1, RDmn, RRmn, ORmn
ORmn1(104, 11037, 189, 11034)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.