Pcor.test: Partial Correlation test of multiple columns

View source: R/Pcor.test.R

Pcor.testR Documentation

Partial Correlation test of multiple columns

Description

Testing partial correlation between many columns of data with the Pearson method.

Usage

  Pcor.test(Data, x, y)

Arguments

Data

a numeric matrix or data.frame

x

names of columns to be tested

y

names of control columns

Details

It performs multiple partial correlation tests. It uses "complete.obs" rows of the x and y columns.

Value

Row names show which columns are used for the test.

Estimate

point estimate of correlation

Df

degrees of freedom

t value

t value of the t distribution

Pr(>|t|)

probability with the t distribution

Author(s)

Kyun-Seop Bae k@acr.kr

Examples

Pcor.test(mtcars, c("mpg", "hp", "qsec"), c("drat", "wt"))

sasLM documentation built on June 15, 2026, 9:07 a.m.