powered by
Risk (proportion) difference between two groups
RD(y1, n1, y2, n2, conf.level=0.95)
The result is a data.frame.
data.frame
proportion from the first group
proportion from the second group
risk difference, p1 - p2
standard error of RD
lower confidence limit of RD
upper confidence limit of RD
positive event count of the test (the first) group
total count of the test (the first) group
positive event count of the control (the second) group
total count of the control (the second) group
confidence level
Kyun-Seop Bae k@acr.kr
It calculates the risk difference between the two groups. No continuity correction here. If you need the percent scale, multiply the output by 100.
RR, OR, RDmn1, RRmn1, ORmn1, RDmn, RRmn, ORmn
RR
OR
RDmn1
RRmn1
ORmn1
RDmn
RRmn
ORmn
RD(104, 11037, 189, 11034) # no continuity correction
Run the code above in your browser using DataLab