| RDmn | R Documentation |
Risk difference and its score confidence interval between two groups with stratification by the Miettinen and Nurminen method
RDmn(d0, conf.level=0.95, eps=1e-8)
d0 |
A |
conf.level |
confidence level |
eps |
an absolute value less than eps is regarded as negligible |
It calculates the risk difference and its score confidence interval between the two groups. The confidence interval is asymmetric, and there is no standard error in the output. If you need the percent scale, multiply the output by 100. This supports stratification. This implementation uses the uniroot function, which usually gives at least 5 significant digits. This can be used for meta-analysis also.
The following output will be returned for each stratum and the common value. There is no standard error.
p1 |
proportion from the first group, y1/n1 |
p2 |
proportion from the second group, y2/n2 |
RD |
risk difference, p1 - p2. The point estimate of the common RD is calculated with the MN weight. |
lower |
lower confidence limit of RD |
upper |
upper confidence limit of RD |
Kyun-Seop Bae k@acr.kr
Miettinen O, Nurminen M. Comparative analysis of two rates. Stat Med 1985;4:213-26
RDmn1, RRmn1, ORmn1, RRmn, ORmn, RDinv, RRinv, ORinv, ORcmh
d1 = matrix(c(25, 339, 28, 335, 23, 370, 40, 364), nrow=2, byrow=TRUE)
colnames(d1) = c("y1", "n1", "y2", "n2")
RDmn(d1)
d2 = data.frame(y1=c(4, 2, 10), n1=c(20, 20, 20), y2=c(8, 11, 2), n2=c(20, 20, 20))
RDmn(d2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.