Risk difference and its score confidence interval between two groups without stratification
RDmn1(y1, n1, y2, n2, conf.level=0.95, eps=1e-8)There is no standard error.
proportion from the first group, y1/n1
proportion from the second group, y2/n2
risk difference, p1 - p2
lower confidence limit of RD
upper confidence limit of RD
positive event count of the test (the first) group
total count of the test (the first) group. The maximum allowable value is 1e8.
positive event count of the control (the second) group
total count of the control (the second) group. The maximum allowable value is 1e8.
confidence level
an absolute value less than eps is regarded as negligible
Kyun-Seop Bae k@acr.kr
It calculates the risk difference and its score confidence interval between the two groups. The confidence interval is asymmetric, and there is no standard error in the output. If you need the percent scale, multiply the output by 100. This does not support stratification. This implementation uses the uniroot function, which usually gives at least 5 significant digits.
Miettinen O, Nurminen M. Comparative analysis of two rates. Stat Med 1985;4:213-26
RRmn1, ORmn1, RDmn, RRmn, ORmn
RDmn1(104, 11037, 189, 11034)
Run the code above in your browser using DataLab