RR: Relative Risk of the two groups

View source: R/RR.R

RRR Documentation

Relative Risk of the two groups

Description

Relative Risk between the two groups

Usage

  RR(y1, n1, y2, n2, conf.level=0.95)

Arguments

y1

positive event count of the test (the first) group

n1

total count of the test (the first) group

y2

positive event count of the control (the second) group

n2

total count of the control (the second) group

conf.level

confidence level

Details

It calculates the relative risk of the two groups. No continuity correction here. If you need the percent scale, multiply the output by 100.

Value

The result is a data.frame.

p1

proportion from the first group

p2

proportion from the second group

RR

relative risk, p1/p2

SElog

standard error of log(RR)

lower

lower confidence limit of RR

upper

upper confidence limit of RR

Author(s)

Kyun-Seop Bae k@acr.kr

See Also

RD, OR, RDmn1, RRmn1, ORmn1, RDmn, RRmn, ORmn

Examples

  RR(104, 11037, 189, 11034) # no continuity correction

sasLM documentation built on June 15, 2026, 9:07 a.m.