RRinv: Relative Risk of two groups with strata by inverse variance...

View source: R/RRinv.R

RRinvR Documentation

Relative Risk of two groups with strata by inverse variance method

Description

Relative risk and its confidence interval of two groups with stratification by the inverse variance method

Usage

  RRinv(d0, conf.level=0.95)

Arguments

d0

A data.frame or matrix, of which each row represents a stratum. This should have four columns named y1, n1, y2, and n2; y1 and y2 for events of each group, n1 and n2 for the sample size of each stratum. The second group is usually the control group.

conf.level

confidence level

Details

It calculates the relative risk and its confidence interval of two groups by the inverse variance method on the log scale. The common relative risk is given by both the fixed effect model and the DerSimonian-Laird random effects model, with Cochran's Q test for heterogeneity. This can be used for meta-analysis also.

Value

RRs

relative risk, its confidence interval, and the percent weights (pwi for the fixed effect model, pwsi for the random effects model) of each stratum

Heterogeneity

Cochran's Q statistic for heterogeneity across the strata and its p-value

tau2

between-strata variance estimated by the method of moments

Fixed

common relative risk and its confidence interval by the fixed effect model with the inverse variance weights

Random

common relative risk and its confidence interval by the DerSimonian-Laird random effects model

Author(s)

Kyun-Seop Bae k@acr.kr

See Also

RDmn1, RRmn1, ORmn1, RDmn, RRmn, ORmn, RDinv, ORinv, ORcmh

Examples

  d1 = matrix(c(25, 339, 28, 335, 23, 370, 40, 364), nrow=2, byrow=TRUE)
  colnames(d1) =  c("y1", "n1", "y2", "n2")
  RRinv(d1)

sasLM documentation built on June 15, 2026, 9:07 a.m.