RRmn: Relative Risk and Score CI of two groups with strata by the...

View source: R/RRmn.R

RRmnR Documentation

Relative Risk and Score CI of two groups with strata by the MN method

Description

Relative risk and its score confidence interval of two groups with stratification by the Miettinen and Nurminen method

Usage

  RRmn(d0, conf.level=0.95, eps=1e-8)

Arguments

d0

A data.frame or matrix, of which each row represents a stratum. This should have four columns named y1, n1, y2, and n2; y1 and y2 for events of each group, n1 and n2 for the sample size of each stratum. The second group is usually the control group.

conf.level

confidence level

eps

an absolute value less than eps is regarded as negligible

Details

It calculates the relative risk and its score confidence interval of the two groups. The confidence interval is asymmetric, and there is no standard error in the output. This supports stratification. This implementation uses the uniroot function, which usually gives at least 5 significant digits, whereas the PropCIs::riskscoreci function uses a cubic equation approximation which gives only about 2 significant digits. This can be used for meta-analysis also.

Value

The following output will be returned for each stratum and the common value. There is no standard error.

p1

proportion from the first group, y1/n1

p2

proportion from the second group, y2/n2

RR

relative risk, p1/p2. The point estimate of the common RR is calculated with the MN weight.

lower

lower confidence limit of RR

upper

upper confidence limit of RR

Author(s)

Kyun-Seop Bae k@acr.kr

References

Miettinen O, Nurminen M. Comparative analysis of two rates. Stat Med 1985;4:213-26

See Also

RDmn1, RRmn1, ORmn1, RDmn, ORmn, RDinv, RRinv, ORinv, ORcmh

Examples

  d1 = matrix(c(25, 339, 28, 335, 23, 370, 40, 364), nrow=2, byrow=TRUE)
  colnames(d1) =  c("y1", "n1", "y2", "n2")
  RRmn(d1)
  d2 = data.frame(y1=c(4, 2, 10), n1=c(20, 20, 20), y2=c(8, 11, 2), n2=c(20, 20, 20))
  RRmn(d2)

sasLM documentation built on June 15, 2026, 9:07 a.m.