| SLICE | R Documentation |
Performs an F test with a given slice term.
SLICE(Formula, Data, Term, By)
Formula |
a conventional formula for a linear model |
Data |
a |
Term |
a factor name (not an interaction) to calculate the sum of squares and do an F test with least square means |
By |
a factor name to be used for slicing |
It performs an F test with a given slice term. It is similar to the SLICE option of SAS PROC GLM.
Returns the sum of squares and its F value and p-value. Row names are the levels of the slice term.
Df |
degrees of freedom |
Sum Sq |
sum of squares for the set of contrasts |
Mean Sq |
mean square |
F value |
F value for the F distribution |
Pr(>F) |
probability of a larger F value |
Kyun-Seop Bae k@acr.kr
SLICE(uptake ~ Type*Treatment, CO2, "Type", "Treatment")
SLICE(uptake ~ Type*Treatment, CO2, "Treatment", "Type")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.