| ScoreCI | R Documentation |
Score confidence interval of a proportion in one group
ScoreCI(y, n, conf.level=0.95)
y |
positive event count of a group |
n |
total count of a group |
conf.level |
confidence level |
It calculates the score confidence interval of a proportion in one group. The confidence interval is asymmetric, and there is no standard error in the output. If you need the percent scale, multiply the output by 100.
The result is a data.frame. There is no standard error.
PE |
point estimate of the proportion |
Lower |
lower confidence limit of the proportion |
Upper |
upper confidence limit of the proportion |
Kyun-Seop Bae k@acr.kr
binom.test, prop.test
ScoreCI(104, 11037)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.