T3MS: Type III Expected Mean Square Formula

View source: R/T3MS.R

T3MSR Documentation

Type III Expected Mean Square Formula

Description

Calculates a formula table for the expected mean square of Type III SS.

Usage

  T3MS(Formula, Data, L0, eps=1e-8)

Arguments

Formula

a conventional formula for a linear model

Data

a data.frame to be analyzed

L0

a matrix of row linear contrasts; if missing, e3 is used

eps

Values less than this are considered as zero.

Details

This is necessary for further hypothesis tests of nesting factors.

Value

A coefficient matrix for Type III expected mean square

Author(s)

Kyun-Seop Bae k@acr.kr

Examples

  T3MS(log(CMAX) ~ SEQ/SUBJ + PRD + TRT, BEdata)

sasLM documentation built on June 15, 2026, 9:07 a.m.