Learn R Programming

sasLM (version 1.0.1)

UCL: Upper Confidence Limit

Description

The estimate of the upper bound of the confidence limit using the t-distribution

Usage

UCL(y, conf.level=0.95)

Value

The estimate of the upper bound of the confidence limit using the t-distribution

Arguments

y

a vector of numerics

conf.level

confidence level

Author

Kyun-Seop Bae k@acr.kr

Details

It removes NA in the input vector.