aov1: ANOVA with Type I SS

View source: R/aov1.R

aov1R Documentation

ANOVA with Type I SS

Description

ANOVA with Type I SS.

Usage

  aov1(Formula, Data, BETA=FALSE, Resid=FALSE)

Arguments

Formula

a conventional formula for a linear model.

Data

a data.frame to be analyzed

BETA

if TRUE, coefficients (parameters) of REG will be returned. This is equivalent to the SOLUTION option of SAS PROC GLM.

Resid

if TRUE, fitted values (y hat) and residuals will be returned

Details

It performs the core function of SAS PROC GLM, and returns Type I SS. This also accepts continuous independent variables.

Value

The result table is comparable to that of SAS PROC ANOVA.

Df

degrees of freedom

Sum Sq

sum of squares for the set of contrasts

Mean Sq

mean square

F value

F value for the F distribution

Pr(>F)

probability of a larger F value

The next returns are optional.

Parameter

Parameter table with standard error, t value, p value. TRUE is 1, and FALSE is 0 in the Estimable column. This is returned only with the BETA=TRUE option.

Fitted

Fitted values or y hat. This is returned only with the Resid=TRUE option.

Residual

Weighted residuals. This is returned only with the Resid=TRUE option.

Author(s)

Kyun-Seop Bae k@acr.kr

Examples

  aov1(uptake ~ Plant + Type + Treatment + conc, CO2)
  aov1(uptake ~ Plant + Type + Treatment + conc, CO2, BETA=TRUE)
  aov1(uptake ~ Plant + Type + Treatment + conc, CO2, Resid=TRUE)
  aov1(uptake ~ Plant + Type + Treatment + conc, CO2, BETA=TRUE, Resid=TRUE)

sasLM documentation built on June 15, 2026, 9:07 a.m.