e1: Get a Contrast Matrix for Type I SS

View source: R/e1.R

e1R Documentation

Get a Contrast Matrix for Type I SS

Description

Makes a contrast matrix for Type I SS using the forward Doolittle method.

Usage

  e1(XpX, eps=1e-8)

Arguments

XpX

the crossproduct of a design or model matrix. This should have appropriate column names.

eps

A value less than this is considered zero.

Details

It makes a contrast matrix for Type I SS. If zapsmall is used, the result becomes less accurate.

Value

A contrast matrix for Type I SS.

Author(s)

Kyun-Seop Bae k@acr.kr

Examples

  x = ModelMatrix(uptake ~ Plant + Type + Treatment + conc, CO2)
  round(e1(crossprod(x$X)), 12)

sasLM documentation built on June 15, 2026, 9:07 a.m.