| is.cor | R Documentation |
Tests if the input matrix is a correlation matrix or not.
is.cor(m, eps=1e-16)
m |
a presumed correlation matrix |
eps |
epsilon value. An absolute value less than this is considered zero. |
A diagonal component does not need to be exactly 1, but it should be close to 1.
TRUE or FALSE
Kyun-Seop Bae k@acr.kr
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.