lfit: Linear Fit

View source: R/lfit.R

lfitR Documentation

Linear Fit

Description

Fits a least squares linear model.

Usage

  lfit(x, y, eps=1e-8)

Arguments

x

a result of ModelMatrix

y

a column vector of the response (dependent) variable

eps

A value less than this is considered zero.

Details

A minimal version of the least squares fit of a linear model

Value

coefficients

beta coefficients

g2

g2 inverse

rank

rank of the model matrix

DFr

degrees of freedom for the residual

SSE

sum of squares error

SST

sum of squares total

DFr2

degrees of freedom of the residual for the beta coefficient

Author(s)

Kyun-Seop Bae k@acr.kr

See Also

ModelMatrix

Examples

  f1 = uptake ~ Type*Treatment + conc
  x = ModelMatrix(f1, CO2)
  y = model.frame(f1, CO2)[,1]
  lfit(x, y)

sasLM documentation built on June 15, 2026, 9:07 a.m.