pB: Plot Confidence and Prediction Bands for Simple Linear...

View source: R/pB.R

pBR Documentation

Plot Confidence and Prediction Bands for Simple Linear Regression

Description

It plots bands of the confidence interval and prediction interval for simple linear regression.

Usage

  pB(Formula, Data, Resol=300, conf.level=0.95, lx, ly, ...)

Arguments

Formula

a formula

Data

a data.frame

Resol

resolution for the output

conf.level

confidence level

lx

x position of the legend

ly

y position of the legend

...

arguments to be passed to plot

Details

It plots. Discard the return values. If lx or ly is missing, the legend position is calculated automatically.

Value

Ignore the return values.

Author(s)

Kyun-Seop Bae k@acr.kr

Examples

  pB(hp ~ disp, mtcars)
  pB(mpg ~ disp, mtcars)

sasLM documentation built on June 15, 2026, 9:07 a.m.