| regD | R Documentation |
regD provides rich diagnostics such as student residual, leverage (hat), Cook's D, studentized deleted residual, DFFITS, and DFBETAS.
regD(Formula, Data)
Formula |
a conventional formula for a linear model |
Data |
a |
It performs the conventional regression analysis. This does not use the g2 inverse; therefore, it cannot handle a singular matrix. If the model (design) matrix is not of full rank, use REG or fewer parameters.
Coefficients |
conventional coefficients summary with Wald statistics |
Diagnostics |
Diagnostics table for detecting outliers or influential/leverage points. This includes the fitted value (Predicted), residual (Residual), standard error of the residual (SE_Resid), studentized residual (Student_Res), hat (Leverage), Cook's D, studentized deleted residual (RStudent), DFFITS, and COVRATIO. |
DFBETAS |
Column names are the names of coefficients. Each row shows how much each coefficient is affected by deleting the corresponding observation. |
Kyun-Seop Bae k@acr.kr
regD(uptake ~ conc, CO2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.