seqCI: Confidence interval with the last Z-value for a group...

View source: R/seqCI.R

seqCIR Documentation

Confidence interval with the last Z-value for a group sequential design

Description

Confidence interval with given upper bounds, times of tests, the last Z-value, and confidence level.

Usage

  seqCI(bi, ti, Zval, conf.level=0.95)

Arguments

bi

upper bound z-values

ti

times for the tests. These should be in [0, 1].

Zval

the last z-value from the observed data. This is not necessarily the planned final Z-value.

conf.level

confidence level

Details

It calculates the confidence interval with given upper bounds, times of tests, the last Z-value, and confidence level. It assumes a two-sided test. mvtnorm::pmvt (with noncentrality) is better than pmvnorm in calculating power, sample size, and confidence interval. However, Lan-DeMets used the multivariate normal rather than the multivariate noncentral t distribution. This function follows Lan-DeMets for consistency with previous results. For the theoretical background, see the reference.

Value

confidence interval of the Z-value for the given confidence level.

Author(s)

Kyun-Seop Bae k@acr.kr

References

Reboussin DM, DeMets DL, Kim K, Lan KKG. Computations for group sequential boundaries using the Lan-DeMets function method. Controlled Clinical Trials. 2000;21:190-207.

Examples

  seqCI(bi = c(2.53, 2.61, 2.57, 2.47, 2.43, 2.38), 
        ti = c(.2292, .3333, .4375, .5833, .7083, .8333), Zval=2.82)

sasLM documentation built on June 15, 2026, 9:07 a.m.