powered by
F-test for the ratio of two groups' variances. This is similar to var.test except using the summarized input.
var.test
vtest(v1, n1, v0, n0, ratio=1, conf.level=0.95)
The output format is very similar to that of var.test.
sample variance of the first (test, active, experimental) group
sample size of the first group
sample variance of the second (reference, control, placebo) group
sample size of the second group
value for the ratio of variances under the null hypothesis
confidence level
Kyun-Seop Bae k@acr.kr
For the confidence interval of one group, use the UNIV function.
UNIV
vtest(10.5^2, 3529, 8.9^2, 5190) # NEJM 388;15 p1386 vtest(2.3^2, 13, 1.5^2, 11, conf.level=0.9) # Red book p240
Run the code above in your browser using DataLab