| CIest | R Documentation |
Get the point estimate and its confidence interval with a given contrast and alpha value using the t distribution.
CIest(Formula, Data, Term, Contrast, conf.level=0.95)
Formula |
a conventional formula for a linear model |
Data |
a |
Term |
a factor name to be estimated |
Contrast |
a level vector. Levels are alphabetically ordered by default. |
conf.level |
confidence level of the confidence interval |
Get the point estimate and its confidence interval with a given contrast and alpha value using the t distribution.
Estimate |
point estimate of the input linear contrast |
Lower CL |
lower confidence limit |
Upper CL |
upper confidence limit |
Std. Error |
standard error of the point estimate |
t value |
value for the t distribution |
Df |
degrees of freedom |
Pr(>|t|) |
probability of a larger absolute t value from the t distribution with the residual degrees of freedom |
Kyun-Seop Bae k@acr.kr
CIest(log(CMAX) ~ SEQ/SUBJ + PRD + TRT, BEdata, "TRT", c(-1, 1), 0.90) # 90% CI
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.