powered by
Get the point estimate and its confidence interval with a given contrast and alpha value using the t distribution.
CIest(Formula, Data, Term, Contrast, conf.level=0.95)
point estimate of the input linear contrast
lower confidence limit
upper confidence limit
standard error of the point estimate
value for the t distribution
degrees of freedom
probability of a larger absolute t value from the t distribution with the residual degrees of freedom
a conventional formula for a linear model
a data.frame to be analyzed
data.frame
a factor name to be estimated
a level vector. Levels are alphabetically ordered by default.
confidence level of the confidence interval
Kyun-Seop Bae k@acr.kr
CIest(log(CMAX) ~ SEQ/SUBJ + PRD + TRT, BEdata, "TRT", c(-1, 1), 0.90) # 90% CI
Run the code above in your browser using DataLab