| Drift | R Documentation |
Calculate the drift value with given upper bounds (z-values), times of test, and power.
Drift(bi, ti=NULL, Power=0.9)
bi |
upper bound z-values |
ti |
times of test. These should be in the range of [0, 1]. If omitted, equal intervals are assumed. |
Power |
target power at the final test |
It calculates the drift value with given upper bound z-values, times of test, and power. If the times of test are not given, equal intervals are assumed. mvtnorm::pmvt (with noncentrality) is better than pmvnorm in calculating power and sample size. However, Lan-DeMets used the multivariate normal rather than the multivariate noncentral t distribution. This function follows Lan-DeMets for consistency with previous results.
Drift value for the given condition
Kyun-Seop Bae k@acr.kr
Reboussin DM, DeMets DL, Kim K, Lan KKG. Computations for group sequential boundaries using the Lan-DeMets function method. Controlled Clinical Trials. 2000;21:190-207.
Drift(seqBound(ti=(1:5)/5)[, "up.bound"])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.