It calculates the drift value with given upper bound z-values, times of test, and power. If the times of test are not given, equal intervals are assumed. mvtnorm::pmvt (with noncentrality) is better than pmvnorm in calculating power and sample size. However, Lan-DeMets used the multivariate normal rather than the multivariate noncentral t distribution. This function follows Lan-DeMets for consistency with previous results.