Learn R Programming

sasLM (version 1.0.1)

ESTM: Estimate Linear Function

Description

Estimates Linear Function with a formula and a dataset.

Usage

ESTM(L, Formula, Data, conf.level=0.95)

Value

Estimate

point estimate of the input linear contrast

Lower CL

lower confidence limit

Upper CL

upper confidence limit

Std. Error

standard error of the point estimate

t value

value for the t distribution

Df

degrees of freedom

Pr(>|t|)

probability of a larger absolute t value from the t distribution with the residual degrees of freedom

Arguments

L

a matrix of linear function rows to be tested

Formula

a conventional formula for a linear model

Data

a data.frame to be analyzed

conf.level

confidence level of the confidence limit

Author

Kyun-Seop Bae k@acr.kr

Details

It tests rows of linear functions. A linear function means a linear combination of estimated coefficients. It is similar to the ESTIMATE statement of SAS PROC GLM. This is a convenient version of the est function.

See Also

est

Examples

Run this code
  ESTM(t(c(0, -1, 1)), uptake ~ Type, CO2) # Quevec - Mississippi 

Run the code above in your browser using DataLab