| OBFBound | R Documentation |
Sequential O'Brien-Fleming upper bounds for the cumulative Z-test on accumulating data. Z values are correlated. This is usually used for group sequential design.
OBFBound(K, alpha=0.05, side=2, ti=NULL, c0=NULL)
K |
count of tests, including the final one |
alpha |
goal alpha value for the last test at time 0. |
side |
1=one-sided test, 2=two-sided test |
ti |
times for test. These should be in [0, 1]. If not specified, equal intervals are assumed. |
c0 |
correlation matrix. If not specified, Brownian motion is assumed. |
It calculates O'Brien-Fleming upper z-bounds and cumulative alpha-values for the repeated test in group sequential design.
The result is a matrix.
ti |
time of test |
z |
O'Brien-Fleming upper z-bound |
cum.alpha |
cumulative alpha-value |
Kyun-Seop Bae k@acr.kr
seqBound, PocockBound
OBFBound(K=2)
OBFBound(K=3)
OBFBound(K=4)
OBFBound(K=5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.