| ORinv | R Documentation |
Odds ratio and its confidence interval of two groups with stratification by the inverse variance method
ORinv(d0, conf.level=0.95)
d0 |
A |
conf.level |
confidence level |
It calculates the odds ratio and its confidence interval of two groups by the inverse variance method. This supports stratification. This can be used for meta-analysis also.
The following output will be returned for each stratum and the common value.
odd1 |
odds from the first group, y1/(n1 - y1) |
odd2 |
odds from the second group, y2/(n2 - y2) |
OR |
odds ratio, odd1/odd2. The point estimate of the common OR is calculated with the inverse variance weights. |
SElog |
standard error of log(OR) |
lower |
lower confidence limit of OR |
upper |
upper confidence limit of OR |
Kyun-Seop Bae k@acr.kr
RDmn1, RRmn1, ORmn1, RDmn, RRmn, ORmn, RDinv, RRinv, ORcmh
d1 = matrix(c(25, 339, 28, 335, 23, 370, 40, 364), nrow=2, byrow=TRUE)
colnames(d1) = c("y1", "n1", "y2", "n2")
ORinv(d1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.