| ORmn | R Documentation |
Odds ratio and its score confidence interval of two groups with stratification by the Miettinen and Nurminen method
ORmn(d0, conf.level=0.95, eps=1e-8)
d0 |
A |
conf.level |
confidence level |
eps |
absolute value less than eps is regarded as negligible |
It calculates the common odds ratio and its score confidence interval of two groups with stratification. The confidence interval is asymmetric, and there is no standard error in the output. For the stratified case, the inverse variance weighted score statistic with the bias correction is used, following Laud. The common odds ratio point estimate is the zero of the weighted score statistic, and the confidence bounds are found with the uniroot function. The result agrees with ratesci::scoreci(contrast="OR", stratified=TRUE, skew=FALSE) to at least 7 significant digits. For a single stratum, it returns the classical Miettinen-Nurminen interval of ORmn1. This can be used for meta-analysis also.
The following output will be returned for each stratum and common value. There is no standard error.
odd1 |
odds from the first group, y1/(n1 - y1). For the common value, it is calculated with the weights at the point estimate. |
odd2 |
odds from the second group, y2/(n2 - y2). For the common value, it is calculated with the weights at the point estimate. |
OR |
odds ratio of the stratum. The common OR is the zero of the inverse variance weighted score statistic. |
lower |
lower confidence limit of OR |
upper |
upper confidence limit of OR |
Kyun-Seop Bae k@acr.kr
Miettinen O, Nurminen M. Comparative analysis of two rates. Stat Med 1985;4:213-26
Laud PJ. Equal-tailed confidence intervals for comparison of rates. Pharmaceutical Statistics 2017;16:334-348
RDmn1, RRmn1, ORmn1, RDmn, RRmn, RDinv, RRinv, ORinv, ORcmh
d1 = matrix(c(25, 339, 28, 335, 23, 370, 40, 364), nrow=2, byrow=TRUE)
colnames(d1) = c("y1", "n1", "y2", "n2")
ORmn(d1)
d2 = data.frame(y1=c(4, 2, 10), n1=c(20, 20, 20), y2=c(8, 11, 2), n2=c(20, 20, 20))
ORmn(d2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.