Odds ratio and its score confidence interval of two groups without stratification
ORmn1(y1, n1, y2, n2, conf.level=0.95, eps=1e-8)There is no standard error.
odds from the first group, y1/(n1 - y1)
odds from the second group, y2/(n2 - y2)
odds ratio, odd1/odd2
lower confidence limit of OR
upper confidence limit of OR
positive event count of the test (the first) group
total count of the test (the first) group
positive event count of the control (the second) group
total count of the control (the second) group
confidence level
absolute value less than eps is regarded as negligible
Kyun-Seop Bae k@acr.kr
It calculates the odds ratio and its score confidence interval of the two groups. The confidence interval is asymmetric, and there is no standard error in the output. This does not support stratification. This implementation uses the uniroot function, which usually gives at least 5 significant digits. In contrast, the PropCIs::orscoreci function uses an incremental or decremental search by a factor of 1.001, which gives less than 3 significant digits.
Miettinen O, Nurminen M. Comparative analysis of two rates. Stat Med 1985;4:213-26
RDmn1, RRmn1, RDmn, RRmn, ORmn
ORmn1(104, 11037, 189, 11034)
Run the code above in your browser using DataLab