powered by
Estimates pairwise differences by a common method.
PDIFF(Formula, Data, Term, conf.level=0.95, adj="lsd", ref, PLOT=FALSE, reverse=FALSE, ...)
Returns a table of expectations, t values and p-values. Output columns may vary according to the adjustment option.
point estimate of the input linear contrast
lower confidence limit
upper confidence limit
standard error of the point estimate
value for the t distribution
degrees of freedom
probability of a larger absolute t value from the t distribution with the residual's degrees of freedom
a conventional formula for a linear model
a data.frame to be analyzed
data.frame
a factor name to be estimated
confidence level of the confidence interval
"lsd", "tukey", "scheffe", "bon", "duncan", or "dunnett" to adjust the p-value and confidence limit
reference or control level for the Dunnett test. If missing, the first level is used, as SAS does.
whether to plot the diffogram
reverse A - B to B - A
arguments to be passed to plot
plot
Kyun-Seop Bae k@acr.kr
It corresponds to the PDIFF option of SAS PROC GLM.
LSM, Diffogram
LSM
Diffogram
PDIFF(uptake ~ Type*Treatment + as.factor(conc), CO2, "as.factor(conc)") PDIFF(uptake ~ Type*Treatment + as.factor(conc), CO2, "as.factor(conc)", adj="tukey")
Run the code above in your browser using DataLab