| Pcor.test | R Documentation |
Testing partial correlation between many columns of data with the Pearson method.
Pcor.test(Data, x, y)
Data |
a numeric matrix or |
x |
names of columns to be tested |
y |
names of control columns |
It performs multiple partial correlation tests. It uses "complete.obs" rows of the x and y columns.
Row names show which columns are used for the test.
Estimate |
point estimate of correlation |
Df |
degrees of freedom |
t value |
t value of the t distribution |
Pr(>|t|) |
probability with the t distribution |
Kyun-Seop Bae k@acr.kr
Pcor.test(mtcars, c("mpg", "hp", "qsec"), c("drat", "wt"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.