powered by
Testing partial correlation between many columns of data with the Pearson method.
Pcor.test(Data, x, y)
Row names show which columns are used for the test.
point estimate of correlation
degrees of freedom
t value of the t distribution
probability with the t distribution
a numeric matrix or data.frame
data.frame
names of columns to be tested
names of control columns
Kyun-Seop Bae k@acr.kr
It performs multiple partial correlation tests. It uses "complete.obs" rows of the x and y columns.
Pcor.test(mtcars, c("mpg", "hp", "qsec"), c("drat", "wt"))
Run the code above in your browser using DataLab