Learn R Programming

sasLM (version 1.0.1)

PocockBound: Pocock (fixed) Bound for the cumulative Z-test with a final target alpha-value

Description

Cumulative alpha values for the cumulative hypothesis test with a fixed upper bound z-value in group sequential design.

Usage

PocockBound(K=2, alpha=0.05, side=2)

Value

a fixed upper bound z-value for the K times repeated hypothesis test with a final alpha-value. Attributes are:

ti

time of test. Equal intervals are assumed.

cum.alpha

cumulative alpha value

Arguments

K

total number of tests

alpha

alpha value at the final test

side

1=one-sided test, 2=two-sided test

Author

Kyun-Seop Bae k@acr.kr

Details

Pocock suggested a fixed upper bound z-value for the cumulative hypothesis test in group sequential designs.

References

Reboussin DM, DeMets DL, Kim K, Lan KKG. Computations for group sequential boundaries using the Lan-DeMets function method. Controlled Clinical Trials. 2000;21:190-207.

See Also

seqBound, OBFBound

Examples

Run this code
  PocockBound(K=2) # Z-value of upper bound for the two-stage design
  PocockBound(K=3) # Z-value of upper bound for the two-stage design
  PocockBound(K=4) # Z-value of upper bound for the two-stage design
  PocockBound(K=5) # Z-value of upper bound for the two-stage design

Run the code above in your browser using DataLab