| RDinv | R Documentation |
Risk difference and its confidence interval between two groups with stratification by the inverse variance method
RDinv(d0, conf.level=0.95)
d0 |
A |
conf.level |
confidence level |
It calculates the risk difference and its confidence interval between two groups by the inverse variance method. The common risk difference is given by both the fixed effect model and the DerSimonian-Laird random effects model, with Cochran's Q test for heterogeneity. If you need the percent scale, multiply the output by 100. This can be used for meta-analysis also.
RDs |
risk difference and its confidence interval of each stratum |
Heterogeneity |
Cochran's Q statistic for heterogeneity across the strata and its p-value |
tau2 |
between-strata variance estimated by the method of moments |
Fixed |
common risk difference, its standard error, and its confidence interval by the fixed effect model with the inverse variance weights |
Random |
common risk difference, its standard error, and its confidence interval by the DerSimonian-Laird random effects model |
Kyun-Seop Bae k@acr.kr
RDmn1, RRmn1, ORmn1, RDmn, RRmn, ORmn, RRinv, ORinv, ORcmh
d1 = matrix(c(25, 339, 28, 335, 23, 370, 40, 364), nrow=2, byrow=TRUE)
colnames(d1) = c("y1", "n1", "y2", "n2")
RDinv(d1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.