RDinv: Risk Difference between two groups with strata by inverse variance method
Description
Risk difference and its confidence interval between two groups with stratification by the inverse variance method
Usage
RDinv(d0, conf.level=0.95)
Value
RDs
risk difference and its confidence interval of each stratum
Heterogeneity
Cochran's Q statistic for heterogeneity across the strata and its p-value
tau2
between-strata variance estimated by the method of moments
Fixed
common risk difference, its standard error, and its confidence interval by the fixed effect model with the inverse variance weights
Random
common risk difference, its standard error, and its confidence interval by the DerSimonian-Laird random effects model
Arguments
d0
A data.frame or matrix, of which each row represents a stratum. This should have four columns named y1, n1, y2, and n2; y1 and y2 for events of each group, n1 and n2 for the sample size of each stratum. The second group is usually the control group.
conf.level
confidence level
Author
Kyun-Seop Bae k@acr.kr
Details
It calculates the risk difference and its confidence interval between two groups by the inverse variance method. The common risk difference is given by both the fixed effect model and the DerSimonian-Laird random effects model, with Cochran's Q test for heterogeneity. If you need the percent scale, multiply the output by 100. This can be used for meta-analysis also.