powered by
Relative Risk between the two groups
RR(y1, n1, y2, n2, conf.level=0.95)
The result is a data.frame.
data.frame
proportion from the first group
proportion from the second group
relative risk, p1/p2
standard error of log(RR)
lower confidence limit of RR
upper confidence limit of RR
positive event count of the test (the first) group
total count of the test (the first) group
positive event count of the control (the second) group
total count of the control (the second) group
confidence level
Kyun-Seop Bae k@acr.kr
It calculates the relative risk of the two groups. No continuity correction here. If you need the percent scale, multiply the output by 100.
RD, OR, RDmn1, RRmn1, ORmn1, RDmn, RRmn, ORmn
RD
OR
RDmn1
RRmn1
ORmn1
RDmn
RRmn
ORmn
RR(104, 11037, 189, 11034) # no continuity correction
Run the code above in your browser using DataLab