| RRinv | R Documentation |
Relative risk and its confidence interval of two groups with stratification by the inverse variance method
RRinv(d0, conf.level=0.95)
d0 |
A |
conf.level |
confidence level |
It calculates the relative risk and its confidence interval of two groups by the inverse variance method on the log scale. The common relative risk is given by both the fixed effect model and the DerSimonian-Laird random effects model, with Cochran's Q test for heterogeneity. This can be used for meta-analysis also.
RRs |
relative risk, its confidence interval, and the percent weights (pwi for the fixed effect model, pwsi for the random effects model) of each stratum |
Heterogeneity |
Cochran's Q statistic for heterogeneity across the strata and its p-value |
tau2 |
between-strata variance estimated by the method of moments |
Fixed |
common relative risk and its confidence interval by the fixed effect model with the inverse variance weights |
Random |
common relative risk and its confidence interval by the DerSimonian-Laird random effects model |
Kyun-Seop Bae k@acr.kr
RDmn1, RRmn1, ORmn1, RDmn, RRmn, ORmn, RDinv, ORinv, ORcmh
d1 = matrix(c(25, 339, 28, 335, 23, 370, 40, 364), nrow=2, byrow=TRUE)
colnames(d1) = c("y1", "n1", "y2", "n2")
RRinv(d1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.