Learn R Programming

sasLM (version 1.0.1)

SLICE: F Test with Slice

Description

Performs an F test with a given slice term.

Usage

SLICE(Formula, Data, Term, By)

Value

Returns the sum of squares and its F value and p-value. Row names are the levels of the slice term.

Df

degrees of freedom

Sum Sq

sum of squares for the set of contrasts

Mean Sq

mean square

F value

F value for the F distribution

Pr(>F)

probability of a larger F value

Arguments

Formula

a conventional formula for a linear model

Data

a data.frame to be analyzed

Term

a factor name (not an interaction) to calculate the sum of squares and do an F test with least square means

By

a factor name to be used for slicing

Author

Kyun-Seop Bae k@acr.kr

Details

It performs an F test with a given slice term. It is similar to the SLICE option of SAS PROC GLM.

Examples

Run this code
  SLICE(uptake ~ Type*Treatment, CO2, "Type", "Treatment") 
  SLICE(uptake ~ Type*Treatment, CO2, "Treatment", "Type") 

Run the code above in your browser using DataLab