ScoreCI: Score Confidence Interval for a Proportion or a Binomial Distribution
Description
Score confidence interval of a proportion in one group
Usage
ScoreCI(y, n, conf.level=0.95)
Value
The result is a data.frame. There is no standard error.
- PE
point estimate of the proportion
- Lower
lower confidence limit of the proportion
- Upper
upper confidence limit of the proportion
Arguments
- y
positive event count of a group
- n
total count of a group
- conf.level
confidence level
Author
Kyun-Seop Bae k@acr.kr
Details
It calculates the score confidence interval of a proportion in one group. The confidence interval is asymmetric, and there is no standard error in the output. If you need the percent scale, multiply the output by 100.