| aov1 | R Documentation |
ANOVA with Type I SS.
aov1(Formula, Data, BETA=FALSE, Resid=FALSE)
Formula |
a conventional formula for a linear model. |
Data |
a |
BETA |
if |
Resid |
if |
It performs the core function of SAS PROC GLM, and returns Type I SS. This also accepts continuous independent variables.
The result table is comparable to that of SAS PROC ANOVA.
Df |
degrees of freedom |
Sum Sq |
sum of squares for the set of contrasts |
Mean Sq |
mean square |
F value |
F value for the F distribution |
Pr(>F) |
probability of a larger F value |
The next returns are optional.
Parameter |
Parameter table with standard error, t value, p value. |
Fitted |
Fitted values or y hat. This is returned only with the |
Residual |
Weighted residuals. This is returned only with the |
Kyun-Seop Bae k@acr.kr
aov1(uptake ~ Plant + Type + Treatment + conc, CO2)
aov1(uptake ~ Plant + Type + Treatment + conc, CO2, BETA=TRUE)
aov1(uptake ~ Plant + Type + Treatment + conc, CO2, Resid=TRUE)
aov1(uptake ~ Plant + Type + Treatment + conc, CO2, BETA=TRUE, Resid=TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.