| aov2 | R Documentation |
ANOVA with Type II SS.
aov2(Formula, Data, BETA=FALSE, Resid=FALSE)
Formula |
a conventional formula for a linear model. |
Data |
a |
BETA |
if |
Resid |
if |
It performs the core function of SAS PROC GLM, and returns Type II SS. This also accepts continuous independent variables.
The result table is comparable to that of SAS PROC ANOVA.
Df |
degrees of freedom |
Sum Sq |
sum of squares for the set of contrasts |
Mean Sq |
mean square |
F value |
F value for the F distribution |
Pr(>F) |
probability of a larger F value |
The next returns are optional.
Parameter |
Parameter table with standard error, t value, p value. |
Fitted |
Fitted values or y hat. This is returned only with the |
Residual |
Weighted residuals. This is returned only with the |
Kyun-Seop Bae k@acr.kr
aov2(uptake ~ Plant + Type + Treatment + conc, CO2)
aov2(uptake ~ Plant + Type + Treatment + conc, CO2, BETA=TRUE)
aov2(uptake ~ Plant + Type + Treatment + conc, CO2, Resid=TRUE)
aov2(uptake ~ Plant + Type + Treatment + conc, CO2, BETA=TRUE, Resid=TRUE)
aov2(uptake ~ Type, CO2)
aov2(uptake ~ Type - 1, CO2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.