| e1 | R Documentation |
Makes a contrast matrix for Type I SS using the forward Doolittle method.
e1(XpX, eps=1e-8)
XpX |
the crossproduct of a design or model matrix. This should have appropriate column names. |
eps |
A value less than this is considered zero. |
It makes a contrast matrix for Type I SS. If zapsmall is used, the result becomes less accurate.
A contrast matrix for Type I SS.
Kyun-Seop Bae k@acr.kr
x = ModelMatrix(uptake ~ Plant + Type + Treatment + conc, CO2)
round(e1(crossprod(x$X)), 12)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.