Learn R Programming

sasLM (version 1.0.1)

e1: Get a Contrast Matrix for Type I SS

Description

Makes a contrast matrix for Type I SS using the forward Doolittle method.

Usage

e1(XpX, eps=1e-8)

Value

A contrast matrix for Type I SS.

Arguments

XpX

the crossproduct of a design or model matrix. This should have appropriate column names.

eps

A value less than this is considered zero.

Author

Kyun-Seop Bae k@acr.kr

Details

It makes a contrast matrix for Type I SS. If zapsmall is used, the result becomes less accurate.

Examples

Run this code
  x = ModelMatrix(uptake ~ Plant + Type + Treatment + conc, CO2)
  round(e1(crossprod(x$X)), 12)

Run the code above in your browser using DataLab