powered by
Makes a contrast matrix for Type I SS using the forward Doolittle method.
e1(XpX, eps=1e-8)
A contrast matrix for Type I SS.
the crossproduct of a design or model matrix. This should have appropriate column names.
A value less than this is considered zero.
Kyun-Seop Bae k@acr.kr
It makes a contrast matrix for Type I SS. If zapsmall is used, the result becomes less accurate.
zapsmall
x = ModelMatrix(uptake ~ Plant + Type + Treatment + conc, CO2) round(e1(crossprod(x$X)), 12)
Run the code above in your browser using DataLab