Learn R Programming

sasLM (version 1.0.1)

is.cor: Is it a correlation matrix?

Description

Tests if the input matrix is a correlation matrix or not.

Usage

is.cor(m, eps=1e-16)

Value

TRUE or FALSE

Arguments

m

a presumed correlation matrix

eps

epsilon value. An absolute value less than this is considered zero.

Author

Kyun-Seop Bae k@acr.kr

Details

A diagonal component does not need to be exactly 1, but it should be close to 1.