powered by
Tests if the input matrix is a correlation matrix or not.
is.cor(m, eps=1e-16)
TRUE or FALSE
a presumed correlation matrix
epsilon value. An absolute value less than this is considered zero.
Kyun-Seop Bae k@acr.kr
A diagonal component does not need to be exactly 1, but it should be close to 1.