powered by
Fits a least squares linear model.
lfit(x, y, eps=1e-8)
beta coefficients
g2 inverse
rank of the model matrix
degrees of freedom for the residual
sum of squares error
sum of squares total
degrees of freedom of the residual for the beta coefficient
a result of ModelMatrix
ModelMatrix
a column vector of the response (dependent) variable
A value less than this is considered zero.
Kyun-Seop Bae k@acr.kr
A minimal version of the least squares fit of a linear model
f1 = uptake ~ Type*Treatment + conc x = ModelMatrix(f1, CO2) y = model.frame(f1, CO2)[,1] lfit(x, y)
Run the code above in your browser using DataLab