| lr | R Documentation |
Coefficients are calculated with the g2 inverse. The output is similar to summary(lm()).
lr(Formula, Data, eps=1e-8)
Formula |
a conventional formula for a linear model |
Data |
a |
eps |
A value less than this is considered zero. |
It uses G2SWEEP to get the g2 inverse. The result is similar to summary(lm()) without options.
The result is comparable to that of SAS PROC REG.
Estimate |
point estimate of parameters, coefficients |
Std. Error |
standard error of the point estimate |
t value |
value for the t distribution |
Pr(>|t|) |
probability of a larger absolute t value from the t distribution with the residual degrees of freedom |
Kyun-Seop Bae k@acr.kr
lr(uptake ~ Plant + Type + Treatment + conc, CO2)
lr(uptake ~ Plant + Type + Treatment + conc - 1, CO2)
lr(uptake ~ Type, CO2)
lr(uptake ~ Type - 1, CO2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.