powered by
Coefficients are calculated with the g2 inverse. The output is similar to summary(lm()).
summary(lm())
lr(Formula, Data, eps=1e-8)
The result is comparable to that of SAS PROC REG.
point estimate of parameters, coefficients
standard error of the point estimate
value for the t distribution
probability of a larger absolute t value from the t distribution with the residual degrees of freedom
a conventional formula for a linear model
a data.frame to be analyzed
data.frame
A value less than this is considered zero.
Kyun-Seop Bae k@acr.kr
It uses G2SWEEP to get the g2 inverse. The result is similar to summary(lm()) without options.
G2SWEEP
lr(uptake ~ Plant + Type + Treatment + conc, CO2) lr(uptake ~ Plant + Type + Treatment + conc - 1, CO2) lr(uptake ~ Type, CO2) lr(uptake ~ Type - 1, CO2)
Run the code above in your browser using DataLab