powered by
Usually, the first step in multiple linear regression is to perform simple linear regressions with each single independent variable.
lr0(Formula, Data)
Each row means one simple linear regression with that row name as the only independent variable.
estimate of the intercept
standard error of the intercept
estimate of the slope
standard error of the slope
R-squared for the simple linear model
p-value of the slope or the model
a conventional formula for a linear model. The intercept will always be added.
a data.frame to be analyzed
data.frame
Kyun-Seop Bae k@acr.kr
It performs simple linear regression for each independent variable.
lr0(uptake ~ Plant + Type + Treatment + conc, CO2) lr0(mpg ~ ., mtcars)
Run the code above in your browser using DataLab