powered by
It plots bands of the confidence interval and prediction interval for simple linear regression.
pB(Formula, Data, Resol=300, conf.level=0.95, lx, ly, ...)
Ignore the return values.
a formula
a data.frame
data.frame
resolution for the output
confidence level
x position of the legend
y position of the legend
arguments to be passed to plot
plot
Kyun-Seop Bae k@acr.kr
It plots. Discard the return values. If lx or ly is missing, the legend position is calculated automatically.
lx
ly
pB(hp ~ disp, mtcars) pB(mpg ~ disp, mtcars)
Run the code above in your browser using DataLab