seqCI: Confidence interval with the last Z-value for a group sequential design
Description
Confidence interval with given upper bounds, times of tests, the last Z-value, and confidence level.
Usage
seqCI(bi, ti, Zval, conf.level=0.95)
Value
confidence interval of the Z-value for the given confidence level.
Arguments
bi
upper bound z-values
ti
times for the tests. These should be in [0, 1].
Zval
the last z-value from the observed data. This is not necessarily the planned final Z-value.
conf.level
confidence level
Author
Kyun-Seop Bae k@acr.kr
Details
It calculates the confidence interval with given upper bounds, times of tests, the last Z-value, and confidence level. It assumes a two-sided test. mvtnorm::pmvt (with noncentrality) is better than pmvnorm in calculating power, sample size, and confidence interval. However, Lan-DeMets used the multivariate normal rather than the multivariate noncentral t distribution. This function follows Lan-DeMets for consistency with previous results. For the theoretical background, see the reference.
References
Reboussin DM, DeMets DL, Kim K, Lan KKG. Computations for group sequential boundaries using the Lan-DeMets function method. Controlled Clinical Trials. 2000;21:190-207.