powered by
This produces essentially the same result as t.test, except using summarized input (sufficient statistics).
t.test
tmtest(m1, s1, n1, m0, s0, n0, conf.level=0.95, nullHypo=0, var.equal=FALSE)
The output format is very similar to that of t.test.
mean of the first (test, active, experimental) group
sample standard deviation of the first group
sample size of the first group
mean of the second (reference, control, placebo) group
sample standard deviation of the second group
sample size of the second group
confidence level
value for the difference of means under the null hypothesis
assumption on the variance equality
Kyun-Seop Bae k@acr.kr
The default is the Welch t-test with the Satterthwaite approximation.
mtest, TTEST, ztest
mtest
TTEST
ztest
tmtest(5.4, 10.5, 3529, 5.1, 8.9, 5190) # NEJM 388;15 p1386 tmtest(5.4, 10.5, 3529, 5.1, 8.9, 5190, var.equal=TRUE)
Run the code above in your browser using DataLab