| tsum2 | R Documentation |
Summarize a continuous dependent (y) variable with two independent (x) variables.
tsum2(d, y, l, u, e=c("Mean", "SD", "N"), h=NULL, ol="", ou="", rm.dup=TRUE,
repl=list(c("length"), c("n")))
d |
a |
y |
y variable name, a continuous variable |
l |
x variable name to be shown on the left side |
u |
x variable name to be shown on the upper side |
e |
a vector of summary function names |
h |
a vector of summary function names for the horizontal subgroup. If |
ol |
order of levels of the left side x variable |
ou |
order of levels of the upper side x variable |
rm.dup |
if |
repl |
a list of strings to replace after summarization. The length of the list should be 2, and both elements should have the same length. |
A convenient summarization function for a continuous variable with two x variables; one on the left side, the other on the upper side.
A data.frame of summarized values. Column names are from the levels of u. Row names are basically from the levels of l.
Kyun-Seop Bae k@acr.kr
tsum, tsum0, tsum1, tsum3
tsum2(CO2, "uptake", "Type", "Treatment")
tsum2(CO2, "uptake", "Type", "conc")
tsum2(CO2, "uptake", "Type", "Treatment",
e=c("mean", "median", "sd", "min", "max", "length"),
ou=c("chilled", "nonchilled"),
repl=list(c("median", "length"), c("med", "n")))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.