Learn R Programming

sasLM (version 1.0.1)

tsum3: Table Summary with 3 independent (x) variables

Description

Summarize a continuous dependent (y) variable with three independent (x) variables.

Usage

tsum3(d, y, l, u, e=c("Mean", "SD", "N"), h=NULL, ol1="", ol2="", ou="", 
        rm.dup=TRUE, repl=list(c("length"), c("n")))

Value

A data.frame of summarized values. Column names are from the levels of u. Row names are basically from the levels of l.

Arguments

d

a data.frame or matrix with column names

y

y variable name, a continuous variable

l

a vector of two x variable names to be shown on the left side. The length should be 2.

u

x variable name to be shown on the upper side

e

a vector of summary function names

h

a list of two vectors of summary function names for the first and second horizontal subgroups. If NULL, it becomes the same as the e argument.

ol1

order of levels of the 1st left side x variable

ol2

order of levels of the 2nd left side x variable

ou

order of levels of the upper side x variable

rm.dup

if TRUE, duplicated names of levels are specified on the first occurrence only.

repl

a list of strings to replace after summarization. The length of the list should be 2, and both elements should have the same length.

Author

Kyun-Seop Bae k@acr.kr

Details

A convenient summarization function for a continuous variable with three x variables; two on the left side, the other on the upper side.

See Also

tsum, tsum0, tsum1, tsum2

Examples

Run this code
  tsum3(CO2, "uptake", c("Type", "Treatment"), "conc")
  tsum3(CO2, "uptake", c("Type", "Treatment"), "conc", 
        e=c("mean", "median", "sd", "min", "max", "length"),
        h=list(c("mean", "sd", "length"), c("mean", "length")),
        ol2=c("chilled", "nonchilled"),
        repl=list(c("median", "length"), c("med", "n")))

Run the code above in your browser using DataLab