powered by
This is similar to the two groups t-test, but using the standard normal (Z) distribution.
ztest(m1, s1, n1, m0, s0, n0, conf.level=0.95, nullHypo=0)
The output format is very similar to that of t.test.
t.test
mean of the first (test, active, experimental) group
known standard deviation of the first group
sample size of the first group
mean of the second (reference, control, placebo) group
known standard deviation of the second group
sample size of the second group
confidence level
value for the difference of means under the null hypothesis
Kyun-Seop Bae k@acr.kr
Use this only for known standard deviations (or variances) or very large sample sizes per group.
mtest, tmtest, TTEST
mtest
tmtest
TTEST
ztest(5.4, 10.5, 3529, 5.1, 8.9, 5190) # NEJM 388;15 p1386
Run the code above in your browser using DataLab